module SaasPayments
  module Webhook
    extend ActiveSupport::Concern
    Stripe.api_key = SaasPayments.config.stripe_secret_key
    SECRET = SaasPayments.config.webhook_secret

    def webhook
      event = parse_event request.body.read
      WebhookService.new(event).process
    rescue ActiveRecord::RecordNotFound => e
      raise SaasPayments::WebhookError, e.message
    rescue StandardError => e
      raise SaasPayments::WebhookError, e.message
    end

    private

    def parse_event(payload)
      if SaasPayments.config.webhook_secret.present?
        header = request.headers['HTTP_STRIPE_SIGNATURE']
        Stripe::Webhook.construct_event payload, header, SECRET
      else
        data = JSON.parse(request.body.read, symbolize_names: true)
        Stripe::Event.construct_from(data)
      end
    end
  end
end
