module SaasPayments
  class ProductsService
    def initialize
      Stripe.api_key = SaasPayments.config.stripe_secret_key
    end

    def sync
      Stripe::Product.all.each { |p| create_product p }
      Stripe::Plan.list.each { |p| create_plan p }
      Stripe::SKU.list.each { |s| create_sku s }
    end

    def shippable(product, on)
      p = Stripe::Product.retrieve(product)
      p.shippable = on
      p.save
    rescue StandardError => e
      puts "ERROR: #{e.message}"
      false
    end

    private

    def create_sku(sku)
      Sku.create! Sku.from_stripe(sku)
    rescue ActiveRecord::RecordInvalid
      Sku.find_by_stripe_id(sku[:id]).update!(Sku.from_stripe(sku))
    end

    def create_product(product)
      Product.create! Product.from_stripe(product)
    rescue ActiveRecord::RecordInvalid
      Product.find_by_stripe_id(product[:id]).update!(Product.from_stripe(product))
    end

    def create_plan(plan)
      Plan.create! Plan.from_stripe(plan)
    rescue ActiveRecord::RecordInvalid
      Plan.find_by_stripe_id(plan[:id]).update!(Plan.from_stripe(plan))
    end
  end
end
