module SaasPayments
  class Webhook::SkuEvent
    def created(data)
      Sku.create!(Sku.from_stripe(data))
    end

    def updated(data)
      sku = Sku.find_by_stripe_id(data[:id])
      raise_not_found(data[:id]) unless sku
      sku.update(Sku.from_stripe(data))
    end

    def deleted(data)
      sku = Sku.find_by_stripe_id(data[:id])
      raise_not_found(data[:id]) unless sku
      sku.delete
    end

    private

    def raise_not_found(id)
      raise ActiveRecord::RecordNotFound.new("Could not find sku with stripe id: #{id}")
    end
  end
end
